California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 66 - LIMITATIONS ON "THREE STRIKES" LAW. SEX CRIMES. PUNISHMENT. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1266307 | CALIFORNIA ORGANIZATION OF POLICE & SHERIFFS (COPS) TO SAVE THREE STRIKES: NO ON 66 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220428 | CITIZENS AGAINST VIOLENT CRIME, YES ON 66, MAJOR FUNDING BY WATCHDOG OVER LEGISLATION FOUNDATION COMMITTEE AND BUSINESS OWNER JERRY KEENAN. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1253820 | CAMPAIGN FOR SENSIBLE SENTENCING, SPONSORED BY F.A.C.T.S., THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1256139 | WATCHDOG OVER LEGISLATION FOUNDATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1267337 | YES ON 66 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270005 | POWERPAC.ORG FIX 3 STRIKES COMMITTEE (YES ON PROPOSITION 66) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1266690 | FIX THREE STRIKES - YES ON 66, A COALITION OF JUSTICE ADVOCATES, LABOR ORGANIZATIONS AND CHURCH LEADERS | SUPPORT